@@ -5,14 +5,14 @@ LPM <- function(returns, const = 0, order = 1, ...){
   N <- length(returns)
   
   # Computing the LPM
-  return(1/N*sum((const-returns[returns<=const])^order)^(1/order))
+  return(1/N*sum((const-returns[returns<=const])^order))
 }
 
 #' @title Influence Function - Lower Partial Moment (LPM)
 #' 
 #' @description \code{IF.LPM} returns the data and plots the shape of either the IF or the IF TS for the LPM
 #'
-#' @param returns Vector of the returns of the asset or portfolio.
+#' @param returns Returns data of the asset or portfolio. This can be a numeric or an xts object.
 #' @param evalShape Evaluation of the shape of the IF risk measure if TRUE. Otherwise, a TS of the IF of the provided returns is computed.
 #' @param retVals Values used to evaluate the shape of the IF.
 #' @param nuisPars Nuisance parameters used for the evaluation of the shape of the IF (if no returns are provided).
@@ -23,8 +23,8 @@ LPM <- function(returns, const = 0, order = 1, ...){
 #' @param order Order of LPM. Can only take values 1 or 2.
 #' @param prewhiten Boolean variable to indicate if the IF TS is pre-whitened (TRUE) or not (FALSE).
 #' @param ar.prewhiten.order Order of AR parameter for the pre-whitening. Default is AR(1).
-#' @param cleanOutliers Boolean variable to indicate whether the pre-whitenning of the influence functions TS should be done through a robust filter.
-#' @param cleanMethod Robust method used to clean outliers from the TS. The choices are "Boudt" and "locScaleRob" for the function. 
+#' @param cleanOutliers Boolean variable to indicate whether outliers are cleaned with a robust location and scale estimator.
+#' @param cleanMethod Robust method used to clean outliers from the TS. The choices are "locScaleRob" (default) and "Boudt" for the function. 
 #' @param alpha.robust Tuning parameter for the quantile of the "Boudt" robust data cleaning algorithm, using the minimum covariance determinant estimator (MCD).
 #' @param eff Tuning parameter for the normal distribution efficiency for the "locScaleRob" robust data cleaning.
 #' @param ... Additional parameters.
