@@ -1,13 +1,13 @@
 #'
-#' @import stats
-#' @import graphics
+#' @importFrom stats approxfun arima density dnorm pnorm qnorm quantile sd
+#' @importFrom graphics plot grid abline
 
 #' @title Influence Function for Available Risk Measures 
 #'
 #' @description \code{IF} returns the data and plots the shape of either the IF or the IF TS for a risk measure specified.
 #' 
-#' @param risk Risk measure.
-#' @param returns Vector of the returns of the asset or portfolio.
+#' @param risk Risk
+#' @param returns Returns data of the asset or portfolio. This can be a numeric or an xts object.
 #' @param evalShape Evaluation of the shape of the IF risk measure if TRUE. Otherwise, a TS of the IF of the provided returns is computed.
 #' @param retVals Values used to evaluate the shape of the IF.
 #' @param nuisPars Nuisance parameters used for the evaluation of the shape of the IF (if no returns are provided).
@@ -16,8 +16,8 @@
 #' @param IFprint If TRUE, the data for the IF shape or the IF TS of the returns is returned.
 #' @param prewhiten Boolean variable to indicate if the IF TS is pre-whitened (TRUE) or not (FALSE).
 #' @param ar.prewhiten.order Order of AR parameter for the pre-whitening. Default is AR(1).
-#' @param cleanOutliers Boolean variable to indicate whether the pre-whitenning of the IF TS should be done through a robust filter.
-#' @param cleanMethod Robust method used to clean outliers from the TS. The choices are "Boudt" and "locScaleRob" for the function. 
+#' @param cleanOutliers Boolean variable to indicate whether outliers are cleaned with a robust location and scale estimator.
+#' @param cleanMethod Robust method used to clean outliers from the TS. The choices are "locScaleRob" (default) and "Boudt" for the function. 
 #' @param alpha.robust Tuning parameter for the quantile of the "Boudt" robust data cleaning algorithm, using the minimum covariance determinant estimator (MCD).
 #' @param eff Tuning parameter for the normal distribution efficiency for the "locScaleRob" robust data cleaning.
 #' @param ... Additional parameters passed on to influence function of risk measure.
@@ -58,7 +58,7 @@ IF <- function(risk,
                ...){
   
   # Available risk measures
-  risk.available <- c("mean", "SD", "VaR", "ES", "SR", "SoR", "ESratio", "VaRratio", "RachR", "LPM", "Omega", "SSD")
+  risk.available <- c("mean", "SD", "VaR", "ES", "SR", "SoR", "ESratio", "VaRratio", "RachR", "LPM", "Omega", "SemiSD")
   
   # Checking if the specified risk measure is available
   if(!(risk %in% risk.available))
@@ -121,7 +121,7 @@ IF <- function(risk,
                           prewhiten=prewhiten, ar.prewhiten.order=ar.prewhiten.order,
                           cleanOutliers=cleanOutliers, cleanMethod=cleanMethod, alpha.robust=alpha.robust, eff=eff,
                           ...),
-         SSD = IF.SSD(returns=returns, evalShape=evalShape, retVals=retVals, nuisPars =nuisPars , k=k,
+         SemiSD = IF.SemiSD(returns=returns, evalShape=evalShape, retVals=retVals, nuisPars =nuisPars , k=k,
                       IFplot=IFplot, IFprint=IFprint,
                       prewhiten=prewhiten, ar.prewhiten.order=ar.prewhiten.order,
                       cleanOutliers=cleanOutliers, cleanMethod=cleanMethod, alpha.robust=alpha.robust, eff=eff,
